@@ -21,6 +21,7 @@ import collections
 import inspect
 import logging
 import os
+import re
 
 import dateutil.parser
 import dateutil.tz
@@ -372,10 +373,16 @@ class WalFileInfo(FieldListFile):
         "time", load=float, doc="WAL file modification time (seconds since epoch)"
     )
     compression = Field("compression", doc="compression type")
+    encryption = Field("encryption", doc="encryption type")
 
     @classmethod
     def from_file(
-        cls, filename, compression_manager=None, unidentified_compression=None, **kwargs
+        cls,
+        filename,
+        compression_manager=None,
+        unidentified_compression=None,
+        encryption_manager=None,
+        **kwargs,
     ):
         """
         Factory method to generate a WalFileInfo from a WAL file.
@@ -387,6 +394,8 @@ class WalFileInfo(FieldListFile):
         :param str filename: the file to inspect
         :param Compressionmanager compression_manager: a compression manager
             which will be used to identify the compression
+        :param EncryptionManager encryption_manager: an encryption manager which
+            will be used to identify the encryption
         :param str unidentified_compression: the compression to set if
             the current schema is not identifiable
         """
@@ -394,11 +403,18 @@ class WalFileInfo(FieldListFile):
         kwargs.setdefault("name", os.path.basename(filename))
         kwargs.setdefault("size", stat.st_size)
         kwargs.setdefault("time", stat.st_mtime)
+        kwargs.setdefault(
+            "encryption", encryption_manager.identify_encryption(filename)
+        )
         if "compression" not in kwargs:
-            kwargs["compression"] = (
-                compression_manager.identify_compression(filename)
-                or unidentified_compression
-            )
+            # If the file is encrypted we are not able to identify any compression
+            if kwargs["encryption"] is not None:
+                kwargs["compression"] = None
+            else:
+                kwargs["compression"] = (
+                    compression_manager.identify_compression(filename)
+                    or unidentified_compression
+                )
         obj = cls(**kwargs)
         obj.filename = "%s.meta" % filename
         obj.orig_filename = filename
@@ -408,7 +424,13 @@ class WalFileInfo(FieldListFile):
         """
         Format the content of this object as a xlogdb line.
         """
-        return "%s\t%s\t%s\t%s\n" % (self.name, self.size, self.time, self.compression)
+        return "%s\t%s\t%s\t%s\t%s\n" % (
+            self.name,
+            self.size,
+            self.time,
+            self.compression,
+            self.encryption,
+        )
 
     @classmethod
     def from_xlogdb_line(cls, line):
@@ -418,21 +440,31 @@ class WalFileInfo(FieldListFile):
         :param str line: a line in the wal database to parse
         :rtype: WalFileInfo
         """
-        try:
-            name, size, time, compression = line.split()
-        except ValueError:
-            # Old format compatibility (no compression)
-            compression = None
-            try:
-                name, size, time = line.split()
-            except ValueError:
-                raise ValueError("cannot parse line: %r" % (line,))
+        parts = line.split()
+        # Checks length to keep compatibility with old xlog files where
+        # compression and/or encryption did not exist yet
+        if len(parts) == 3:
+            name, size, time, compression, encryption = parts + [None, None]
+        elif len(parts) == 4:
+            name, size, time, compression, encryption = parts + [None]
+        elif len(parts) == 5:
+            name, size, time, compression, encryption = parts
+        else:
+            raise ValueError("cannot parse line: %r" % (line,))
         # The to_xlogdb_line method writes None values as literal 'None'
         if compression == "None":
             compression = None
+        if encryption == "None":
+            encryption = None
         size = int(size)
         time = float(time)
-        return cls(name=name, size=size, time=time, compression=compression)
+        return cls(
+            name=name,
+            size=size,
+            time=time,
+            compression=compression,
+            encryption=encryption,
+        )
 
     def to_json(self):
         """
@@ -484,6 +516,14 @@ class BackupInfo(FieldListFile):
         NONE,
     )
 
+    # Backup types according to `backup_method``
+    FULL = "full"
+    INCREMENTAL = "incremental"
+    RSYNC = "rsync"
+    SNAPSHOT = "snapshot"
+    NOT_INCREMENTAL = (FULL, RSYNC, SNAPSHOT)
+    BACKUP_TYPE_ALL = (FULL, INCREMENTAL, RSYNC, SNAPSHOT)
+
     version = Field("version", load=int)
     pgdata = Field("pgdata")
     # Parse the tablespaces as a literal Python list of namedtuple
@@ -533,6 +573,8 @@ class BackupInfo(FieldListFile):
 
     cluster_size = Field("cluster_size", load=int)
 
+    encryption = Field("encryption")
+
     __slots__ = "backup_id", "backup_version"
 
     _hide_if_null = ("backup_name", "snapshots_info")
@@ -858,12 +900,19 @@ class LocalBackupInfo(BackupInfo):
 
     def detect_backup_id(self):
         """
-        Detect the backup ID from the name of the parent dir of the info file
+        Detect the backup ID from the file name or parent directory name.
+
+        .. note::
+            The ``backup.info`` file was relocated and renamed in version 3.13.2 to
+            also contain the backup id as a prefix. In previous versions, the parent
+            directory of the file was named with the backup id. This method handles
+            both cases.
         """
         if self.filename:
+            match = re.match(r"^(.+?)-backup\.info$", os.path.basename(self.filename))
+            if match:
+                return match.group(1)
             return os.path.basename(os.path.dirname(self.filename))
-        else:
-            return None
 
     def get_basebackup_directory(self):
         """
@@ -914,14 +963,35 @@ class LocalBackupInfo(BackupInfo):
         # Return the built path
         return os.path.join(*path)
 
-    def get_filename(self):
+    def get_filename(self, write=False):
         """
-        Get the default filename for the backup.info file based on
-        backup ID and server directory for base backups
+        Get the default file path for the backup.info file.
+
+        :param bool write: if the file is to be written or not.
+
+        .. note::
+            The ``backup.info`` file was relocated and renamed in version 3.13.2 to
+            also contain the backup id as a prefix. In previous versions, it lived
+            inside the backup directory alongside the data directory. This method
+            handles both paths.
+
+            When writing, always write to the new path. When reading, it could be that
+            a user just migrated to the new version, so we also handle reading from the
+            old path.
         """
-        return os.path.join(self.get_basebackup_directory(), "backup.info")
+        path = os.path.join(self.server.meta_directory, f"{self.backup_id}-backup.info")
+        old_path = os.path.join(self.get_basebackup_directory(), "backup.info")
+        if write or os.path.exists(path) or not os.path.exists(old_path):
+            return path
+        return old_path
 
     def save(self, filename=None, file_object=None):
+        # Update the filename before saving to ensure we're using the correct value
+        # It could be that a user just migrated to version 3.13.2, which relocated the
+        # backup.info path. In this case, the file was read from the old path but has
+        # to be written to the new path
+        if not filename:
+            self.filename = self.get_filename(write=True)
         if not file_object:
             # Make sure the containing directory exists
             filename = filename or self.filename
@@ -1056,28 +1126,14 @@ class LocalBackupInfo(BackupInfo):
                 return False
         return True
 
-    def is_full_and_eligible_for_incremental(self):
+    @property
+    def is_full(self):
         """
-        Check if this is a full backup taken with `postgres` method and which is
-        eligible to be a parent for an incremental backup.
+        Check if this is a full backup.
 
-        .. note::
-            Only consider backups which are eligible for Postgres core
-            incremental backups:
-
-            * backup_method = ``postgres``
-            * summarize_wal = ``on``
-            * is_incremental = ``False``
-
-        :return bool: True if it's a full backup or False if not.
+        :return bool: ``True`` if it's a full backup or ``False`` if not.
         """
-        if (
-            self.mode == "postgres"
-            and self.summarize_wal == "on"
-            and not self.is_incremental
-        ):
-            return True
-        return False
+        return self.backup_type not in ("snapshot", "incremental")
 
     @property
     def is_orphan(self):
@@ -1088,11 +1144,26 @@ class LocalBackupInfo(BackupInfo):
         a non-empty backup.info file. This may indicate an incomplete delete operation.
 
         :return bool: ``True`` if the backup is an orphan, ``False`` otherwise.
+
+        .. note::
+            The ``backup.info`` file was relocated and renamed in version 3.13.2 to
+            also contain the backup id as a prefix. In previous versions, the parent
+            directory of the file was named with the backup id. This method handles
+            both cases.
         """
+        if self.status == BackupInfo.EMPTY:
+            return False
         backup_dir = self.get_basebackup_directory()
-        backup_info_path = os.path.join(backup_dir, "backup.info")
-        if os.path.exists(backup_dir) and os.path.exists(backup_info_path):
-            if len(os.listdir(backup_dir)) == 1 and self.status != BackupInfo.EMPTY:
+        # In the >= 3.13.2 structure, it is considered orphan if the backup.info exists
+        # in the server meta directory while no directory related to the backup exists
+        backup_info_path = self.get_filename()
+        if os.path.exists(backup_info_path) and not os.path.exists(backup_dir):
+            return True
+        # In the < 3.13.2 structure, the backup.info lived inside the backup directory.
+        # In this case, it is considered orphan if the backup.info exists alone in there
+        old_backup_info_path = os.path.join(backup_dir, "backup.info")
+        if os.path.exists(backup_dir) and os.path.exists(old_backup_info_path):
+            if len(os.listdir(backup_dir)) == 1:
                 return True
         return False
 
@@ -1133,3 +1204,57 @@ class SyntheticBackupInfo(LocalBackupInfo):
     def get_basebackup_directory(self):
         """Get the backup directory based on its base directory"""
         return os.path.join(self.base_directory, self.backup_id)
+
+
+class VolatileBackupInfo(LocalBackupInfo):
+    def __init__(
+        self, server, base_directory, backup_id=None, info_file=None, **kwargs
+    ):
+        """
+        A class to hold temporary, in-memory updates on top of a
+        :class:`LocalBackupInfo` object.
+
+        This class allows modification of certain fields of a :class:`LocalBackupInfo`
+        object without affecting the actual backup file on disk. It is designed to
+        support methods like :meth:`RecoveryExecutor._decrypt_backup`, where custom,
+        situational updates to backup information are necessary for processing, such as
+        custom tablespace mappings during backup decompression or combination.
+
+        The :class:`VolatileBackupInfo` does not persist changes to the disk, ensuring
+        that only in-memory instances are updated, while the original
+        :class:`BackupInfo` remains unaltered.
+
+        :param barman.server.Server server: The server of the
+            :class:`LocalBackupInfo`.
+        :param str base_directory: The directory where this backup is stored,
+            essentially an override to the
+            :attr:`barman.config.ServerConfig.basebackups_directory` configuration
+            option.
+        :param str|None backup_id: The backup id of the backup.
+        :param None|str|TextIO info_file: The path to an existing ``backup.info`` file,
+        or
+            a file-like object from which to read the backup information.
+        """
+        self.base_directory = base_directory
+        super(VolatileBackupInfo, self).__init__(server, info_file, backup_id, **kwargs)
+
+    def get_basebackup_directory(self):
+        """
+        Retrieve the full path to the base backup directory for this backup.
+
+        This method constructs the path to the directory where the backup is stored
+        based on the provided :attr:`base_directory` and :attr:`backup_id`. It is
+        particularly useful for scenarios where the backup directory is customized or
+        overridden.
+
+        :return str: The full path to the base backup directory.
+        """
+        return os.path.join(self.base_directory, self.backup_id)
+
+    def save(self, *args, **kwargs):
+        """
+        Override the save method to prevent its usage.
+
+        :raises NotImplementedError: This method is not implemented.
+        """
+        raise NotImplementedError("The save method is not implemented.")
